==> rh-quarkus-platform-3.2.6-src.zip: rh-quarkus-platform-3.2.6.GA-src/opentelemetry-instrumentation-annotations-support-1.25.0-alpha/instrumentation/rxjava/rxjava-3.1.1/library/src/main/java/io/opentelemetry/instrumentation/rxjava/v3_1_1/TracingConditionalSubscriber.java <==
/*
 * Copyright The OpenTelemetry Authors
 * SPDX-License-Identifier: Apache-2.0
 */

// Includes work from:
/*
 * Copyright 2018 LINE Corporation
 *
 * LINE Corporation licenses this file to you under the Apache License,
 * version 2.0 (the "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at:
 *
 *   https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */

package io.opentelemetry.instrumentation.rxjava.v3_1_1;

import io.opentelemetry.context.Context;
import io.opentelemetry.context.Scope;
import io.reactivex.rxjava3.internal.subscribers.BasicFuseableConditionalSubscriber;
import io.reactivex.rxjava3.operators.ConditionalSubscriber;
import io.reactivex.rxjava3.operators.QueueSubscription;

class TracingConditionalSubscriber<T> extends BasicFuseableConditionalSubscriber<T, T> {

  private final Context context;

  TracingConditionalSubscriber(ConditionalSubscriber<? super T> downstream, Context context) {
    super(downstream);
    this.context = context;
  }

  @Override
  public boolean tryOnNext(T t) {
    try (Scope ignored = context.makeCurrent()) {
      return downstream.tryOnNext(t);
    }
  }

  @Override
  public void onNext(T t) {
    try (Scope ignored = context.makeCurrent()) {
      downstream.onNext(t);
    }
  }

  @Override
  public void onError(Throwable t) {
    try (Scope ignored = context.makeCurrent()) {
      downstream.onError(t);
    }
  }

  @Override
  public void onComplete() {
    try (Scope ignored = context.makeCurrent()) {
      downstream.onComplete();
    }
  }

  @Override
  public int requestFusion(int mode) {
    QueueSubscription<T> qs = this.qs;
    if (qs != null) {
      int m = qs.requestFusion(mode);
      sourceMode = m;
      return m;
    }
    return NONE;
  }

  @Override
  public T poll() throws Throwable {
    return qs.poll();
  }
}

==> rh-quarkus-platform-3.2.9-src.zip: rh-quarkus-platform-3.2.9.GA-src/opentelemetry-instrumentation-annotations-support-1.25.0-alpha/instrumentation/rxjava/rxjava-3.0/library/src/main/java/io/opentelemetry/instrumentation/rxjava/v3_0/TracingConditionalSubscriber.java <==
/*
 * Copyright The OpenTelemetry Authors
 * SPDX-License-Identifier: Apache-2.0
 */

// Includes work from:
/*
 * Copyright 2018 LINE Corporation
 *
 * LINE Corporation licenses this file to you under the Apache License,
 * version 2.0 (the "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at:
 *
 *   https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */

package io.opentelemetry.instrumentation.rxjava.v3_0;

import io.opentelemetry.context.Context;
import io.opentelemetry.context.Scope;
import io.reactivex.rxjava3.internal.fuseable.ConditionalSubscriber;
import io.reactivex.rxjava3.internal.fuseable.QueueSubscription;
import io.reactivex.rxjava3.internal.subscribers.BasicFuseableConditionalSubscriber;

class TracingConditionalSubscriber<T> extends BasicFuseableConditionalSubscriber<T, T> {

  private final Context context;

  TracingConditionalSubscriber(ConditionalSubscriber<? super T> downstream, Context context) {
    super(downstream);
    this.context = context;
  }

  @Override
  public boolean tryOnNext(T t) {
    try (Scope ignored = context.makeCurrent()) {
      return downstream.tryOnNext(t);
    }
  }

  @Override
  public void onNext(T t) {
    try (Scope ignored = context.makeCurrent()) {
      downstream.onNext(t);
    }
  }

  @Override
  public void onError(Throwable t) {
    try (Scope ignored = context.makeCurrent()) {
      downstream.onError(t);
    }
  }

  @Override
  public void onComplete() {
    try (Scope ignored = context.makeCurrent()) {
      downstream.onComplete();
    }
  }

  @Override
  public int requestFusion(int mode) {
    QueueSubscription<T> qs = this.qs;
    if (qs != null) {
      int m = qs.requestFusion(mode);
      sourceMode = m;
      return m;
    }
    return NONE;
  }

  @Override
  public T poll() throws Throwable {
    return qs.poll();
  }
}
